@@ -26,7 +26,7 @@ bool Synchronous::enterLoop()
   TQWidget *dummy = 0;
   if ( tqApp->type()!=TQApplication::Tty ) {
     dummy = new TQWidget(0, 0, WType_Dialog | WShowModal);
-    dummy->setFocusPolicy(TQ_NoFocus);
+    dummy->setFocusPolicy(TQWidget::NoFocus);
     tqt_enter_modal(dummy);
   }
   TQApplication::eventLoop()->enterLoop();
