@@ -181,7 +181,7 @@ void TreeListDialog::pageDestroyed(TQObject *object)
   TQListViewItemIterator it(_listView);
   for (; it.current(); ++it) {
     Item *item = static_cast<Item *>(it.current());
-    if ( TQT_BASE_OBJECT(item->_page)!=TQT_BASE_OBJECT(object) ) continue;
+    if ( item->_page!=object ) continue;
     delete item;
     break;
   }
