@@ -34,7 +34,7 @@
 // * use TDEListView
 class EditListBox : public TQFrame
 {
-Q_OBJECT
+TQ_OBJECT
   
    public:
       enum Mode { DuplicatesDisallowed, DuplicatesAllowed, DuplicatesCheckedAtEntering };
