@@ -45,7 +45,7 @@ bool ListView::eventFilter(TQObject *o, TQEvent *e)
   TQValueList<EditListViewItem *>::const_iterator it;
   for (it=_editItems.begin(); it!=_editItems.end(); ++it) {
     for (uint i=0; i<(*it)->_editWidgets.count(); i++) {
-      if ( TQT_BASE_OBJECT((*it)->_editWidgets[i])==TQT_BASE_OBJECT(o) ) {
+      if ( (*it)->_editWidgets[i]==o ) {
         //tqDebug("event %i", e->type());
         switch (e->type()) {
           case TQEvent::KeyPress: {
