@@ -62,7 +62,7 @@ extern void text(const TQString &text, Log::ShowMode show);
 //----------------------------------------------------------------------------
 class PopupButton : public KPushButton
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   PopupButton(TQWidget *parent = 0, const char *name = 0);
@@ -87,7 +87,7 @@ private:
 //-----------------------------------------------------------------------------
 class Splitter : public TQSplitter
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Splitter(const TQValueList<int> &defaultSizes, Qt::Orientation orientation,
@@ -111,7 +111,7 @@ public:
 //-----------------------------------------------------------------------------
 class SeparatorWidget : public TQFrame
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   SeparatorWidget(TQWidget *parent) : TQFrame(parent, "separator") {
@@ -124,7 +124,7 @@ public:
 //-----------------------------------------------------------------------------
 class TabBar : public KTabBar
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   TabBar(TQWidget *parent = 0, const char *name = 0);
@@ -140,7 +140,7 @@ private:
 
 class TabWidget : public KTabWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   TabWidget(TQWidget *parent = 0, const char *name = 0);
@@ -154,7 +154,7 @@ protected:
 //-----------------------------------------------------------------------------
 class ComboBox : public TQComboBox
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ComboBox(TQWidget *parent = 0, const char *name = 0);
