@@ -26,7 +26,7 @@ namespace Pic
 //-----------------------------------------------------------------------------
 class BankWidget : public TQFrame
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   BankWidget(uint bank, TQWidget *parent);
@@ -60,7 +60,7 @@ private:
 //-----------------------------------------------------------------------------
 class RegisterView : public Register::View
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   RegisterView(TQWidget *parent);
